diff --git a/NTwain/Data/CapReadOut.cs b/NTwain/Data/CapReadOut.cs
index bfa9023..4d7920a 100644
--- a/NTwain/Data/CapReadOut.cs
+++ b/NTwain/Data/CapReadOut.cs
@@ -1,4 +1,5 @@
-using NTwain.Values;
+using NTwain.Properties;
+using NTwain.Values;
using System;
using System.Collections.Generic;
using System.Linq;
@@ -28,7 +29,7 @@ namespace NTwain.Data
public static CapReadOut ReadValue(TWCapability capability)
{
if (capability == null) { throw new ArgumentNullException("capability"); }
- if (capability.Container == IntPtr.Zero) { throw new ArgumentException("Capability contains no data.", "capability"); }
+ if (capability.Container == IntPtr.Zero) { throw new ArgumentException(Resources.CapHasNoData, "capability"); }
IntPtr baseAddr = IntPtr.Zero;
try
@@ -57,7 +58,7 @@ namespace NTwain.Data
ContainerType = capability.ContainerType,
}.ReadRangeValue(baseAddr);
default:
- throw new ArgumentException(string.Format("Capability has invalid container type {0}.", capability.ContainerType), "capability");
+ throw new ArgumentException(string.Format(Resources.CapHasBadContainer, capability.ContainerType), "capability");
}
}
finally
diff --git a/NTwain/Data/TypesExtended.cs b/NTwain/Data/TypesExtended.cs
index b270121..f01554a 100644
--- a/NTwain/Data/TypesExtended.cs
+++ b/NTwain/Data/TypesExtended.cs
@@ -688,10 +688,10 @@ namespace NTwain.Data
void SetOneValue(TWOneValue value)
{
if (value == null) { throw new ArgumentNullException("value"); }
- if (ContainerType != Values.ContainerType.OneValue) { throw new ArgumentException(Resources.BadContainerType, "value"); }
+ ContainerType = Values.ContainerType.OneValue;
// since one value can only house UInt32 we will not allow type size > 4
- if (TypeReader.GetItemTypeSize(value.ItemType) > 4) { throw new ArgumentException("Invalid one value type"); }
+ if (TypeReader.GetItemTypeSize(value.ItemType) > 4) { throw new ArgumentException(string.Format(Resources.BadValueType, "TWOneValue")); }
_hContainer = MemoryManager.Instance.Allocate((uint)Marshal.SizeOf(value));
if (_hContainer != IntPtr.Zero)
@@ -704,7 +704,7 @@ namespace NTwain.Data
void SetEnumValue(TWEnumeration value)
{
if (value == null) { throw new ArgumentNullException("value"); }
- if (ContainerType != Values.ContainerType.Enum) { throw new ArgumentException(Resources.BadContainerType, "value"); }
+ ContainerType = Values.ContainerType.Enum;
Int32 valueSize = value.ItemOffset + value.ItemList.Length * TypeReader.GetItemTypeSize(value.ItemType);
@@ -730,10 +730,10 @@ namespace NTwain.Data
void SetRangeValue(TWRange value)
{
if (value == null) { throw new ArgumentNullException("value"); }
- if (ContainerType != Values.ContainerType.Range) { throw new ArgumentException(Resources.BadContainerType, "value"); }
+ ContainerType = Values.ContainerType.Range;
// since range value can only house UInt32 we will not allow type size > 4
- if (TypeReader.GetItemTypeSize(value.ItemType) > 4) { throw new ArgumentException("Invalid range value type"); }
+ if (TypeReader.GetItemTypeSize(value.ItemType) > 4) { throw new ArgumentException(string.Format(Resources.BadValueType, "TWRange")); }
_hContainer = MemoryManager.Instance.Allocate((uint)Marshal.SizeOf(value));
if (_hContainer != IntPtr.Zero)
@@ -1297,7 +1297,7 @@ namespace NTwain.Data
///
/// Tag identifying an information.
///
- public ushort InfoID { get { return _infoID; } }
+ public ExtendedImageInfo InfoID { get { return (ExtendedImageInfo)_infoID; } }
///
/// Item data type.
///
diff --git a/NTwain/DataTransferredEventArgs.cs b/NTwain/DataTransferredEventArgs.cs
index 32a60e6..d34c6ce 100644
--- a/NTwain/DataTransferredEventArgs.cs
+++ b/NTwain/DataTransferredEventArgs.cs
@@ -42,5 +42,13 @@ namespace NTwain
/// The final image information.
///
public TWImageInfo ImageInfo { get; internal set; }
+
+ ///
+ /// Gets the extended image information if applicable.
+ ///
+ ///
+ /// The extended image information.
+ ///
+ public TWExtImageInfo ExImageInfo { get; internal set; }
}
}
\ No newline at end of file
diff --git a/NTwain/MemoryManager.cs b/NTwain/MemoryManager.cs
index e2e434c..c7d456d 100644
--- a/NTwain/MemoryManager.cs
+++ b/NTwain/MemoryManager.cs
@@ -1,4 +1,5 @@
using NTwain.Data;
+using NTwain.Properties;
using System;
using System.Collections.Generic;
using System.Linq;
@@ -52,7 +53,7 @@ namespace NTwain
if (retVal == IntPtr.Zero)
{
- throw new OutOfMemoryException("Failed to allocate requested memory.");
+ throw new OutOfMemoryException(Resources.MemAllocError);
}
return retVal;
}
diff --git a/NTwain/MessageLoop.cs b/NTwain/MessageLoop.cs
index 6474d5f..af13a14 100644
--- a/NTwain/MessageLoop.cs
+++ b/NTwain/MessageLoop.cs
@@ -1,4 +1,5 @@
-using NTwain.Triplets;
+using NTwain.Properties;
+using NTwain.Triplets;
using System;
using System.Collections.Generic;
using System.Diagnostics;
@@ -65,14 +66,14 @@ namespace NTwain
public void BeginInvoke(Action action)
{
- if (_dispatcher == null) { throw new InvalidOperationException("Message loop has not started yet."); }
+ if (_dispatcher == null) { throw new InvalidOperationException(Resources.MsgLoopUnavailble); }
_dispatcher.BeginInvoke(DispatcherPriority.Normal, action);
}
public void Invoke(Action action)
{
- if (_dispatcher == null) { throw new InvalidOperationException("Message loop has not started yet."); }
+ if (_dispatcher == null) { throw new InvalidOperationException(Resources.MsgLoopUnavailble); }
if (_dispatcher.CheckAccess())
{
diff --git a/NTwain/Properties/Resources.Designer.cs b/NTwain/Properties/Resources.Designer.cs
index 3400235..a251971 100644
--- a/NTwain/Properties/Resources.Designer.cs
+++ b/NTwain/Properties/Resources.Designer.cs
@@ -1,7 +1,7 @@
//------------------------------------------------------------------------------
//
// This code was generated by a tool.
-// Runtime Version:4.0.30319.18034
+// Runtime Version:4.0.30319.34014
//
// Changes to this file may cause incorrect behavior and will be lost if
// the code is regenerated.
@@ -61,11 +61,29 @@ namespace NTwain.Properties {
}
///
- /// Looks up a localized string similar to The specified container type does not match the data..
+ /// Looks up a localized string similar to Invalid value type for {0}..
///
- internal static string BadContainerType {
+ internal static string BadValueType {
get {
- return ResourceManager.GetString("BadContainerType", resourceCulture);
+ return ResourceManager.GetString("BadValueType", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Capability has invalid container type {0}..
+ ///
+ internal static string CapHasBadContainer {
+ get {
+ return ResourceManager.GetString("CapHasBadContainer", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Capability contains no data..
+ ///
+ internal static string CapHasNoData {
+ get {
+ return ResourceManager.GetString("CapHasNoData", resourceCulture);
}
}
@@ -77,5 +95,32 @@ namespace NTwain.Properties {
return ResourceManager.GetString("MaxStringLengthExceeded", resourceCulture);
}
}
+
+ ///
+ /// Looks up a localized string similar to Failed to allocate requested memory..
+ ///
+ internal static string MemAllocError {
+ get {
+ return ResourceManager.GetString("MemAllocError", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Message loop has not started yet..
+ ///
+ internal static string MsgLoopUnavailble {
+ get {
+ return ResourceManager.GetString("MsgLoopUnavailble", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Source name is required..
+ ///
+ internal static string SourceRequired {
+ get {
+ return ResourceManager.GetString("SourceRequired", resourceCulture);
+ }
+ }
}
}
diff --git a/NTwain/Properties/Resources.resx b/NTwain/Properties/Resources.resx
index 1989418..7da67ef 100644
--- a/NTwain/Properties/Resources.resx
+++ b/NTwain/Properties/Resources.resx
@@ -117,10 +117,25 @@
System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
- The specified container type does not match the data.
+
+ Invalid value type for {0}.
+
+
+ Capability has invalid container type {0}.
+
+
+ Capability contains no data.
The string value has exceeded the maximum length allowed.
+
+ Failed to allocate requested memory.
+
+
+ Message loop has not started yet.
+
+
+ Source name is required.
+
\ No newline at end of file
diff --git a/NTwain/Properties/VersionInfo.cs b/NTwain/Properties/VersionInfo.cs
index e24e7ac..9266a70 100644
--- a/NTwain/Properties/VersionInfo.cs
+++ b/NTwain/Properties/VersionInfo.cs
@@ -14,6 +14,6 @@ namespace NTwain
// keep this same in majors releases
public const string Release = "0.11.0.0";
// change this for each nuget release
- public const string Build = "0.11.2";
+ public const string Build = "0.11.3";
}
}
\ No newline at end of file
diff --git a/NTwain/TransferErrorEventArgs.cs b/NTwain/TransferErrorEventArgs.cs
index 3246656..28e42f9 100644
--- a/NTwain/TransferErrorEventArgs.cs
+++ b/NTwain/TransferErrorEventArgs.cs
@@ -13,7 +13,7 @@ namespace NTwain
public class TransferErrorEventArgs : EventArgs
{
///
- /// Gets the return code.
+ /// Gets the return code from the transfer.
///
///
/// The return code.
diff --git a/NTwain/TwainSession.cs b/NTwain/TwainSession.cs
index e05dadc..8940ad8 100644
--- a/NTwain/TwainSession.cs
+++ b/NTwain/TwainSession.cs
@@ -1,4 +1,5 @@
using NTwain.Data;
+using NTwain.Properties;
using NTwain.Triplets;
using NTwain.Values;
using System;
@@ -21,7 +22,7 @@ namespace NTwain
public class TwainSession : ITwainStateInternal, ITwainOperation
{
///
- /// Initializes a new instance of the class.
+ /// Initializes a new instance of the class.
///
/// The app id.
///
@@ -293,7 +294,7 @@ namespace NTwain
/// Source name is required.;sourceProductName
public ReturnCode OpenSource(string sourceProductName)
{
- if (string.IsNullOrEmpty(sourceProductName)) { throw new ArgumentException("Source name is required.", "sourceProductName"); }
+ if (string.IsNullOrEmpty(sourceProductName)) { throw new ArgumentException(Resources.SourceRequired, "sourceProductName"); }
ReturnCode rc = ReturnCode.Success;
MessageLoop.Instance.Invoke(() =>
@@ -517,7 +518,7 @@ namespace NTwain
/// The type of the event arguments.
/// The on event function.
/// The handler.
- /// The instance containing the event data.
+ /// The TEventArgs instance containing the event data.
void SafeSyncableRaiseOnEvent(Action onEventFunc, EventHandler handler, TEventArgs e) where TEventArgs : EventArgs
{
var syncer = SynchronizationContext;
@@ -883,6 +884,14 @@ namespace NTwain
{
State = 7;
TWImageInfo imgInfo;
+ TWExtImageInfo extInfo = null;
+ if (SupportedCaps.Contains(CapabilityId.ICapExtImageInfo))
+ {
+ if (DGImage.ExtImageInfo.Get(out extInfo) != ReturnCode.Success)
+ {
+ extInfo = null;
+ }
+ }
if (DGImage.ImageInfo.Get(out imgInfo) != ReturnCode.Success)
{
imgInfo = null;
@@ -891,7 +900,13 @@ namespace NTwain
{
lockedPtr = MemoryManager.Instance.Lock(dataPtr);
}
- SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs { NativeData = lockedPtr, ImageInfo = imgInfo });
+ SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs
+ {
+ NativeData = lockedPtr,
+ ImageInfo = imgInfo,
+ ExImageInfo = extInfo
+ });
+ if (extInfo != null) { extInfo.Dispose(); }
}
else
{
@@ -932,11 +947,25 @@ namespace NTwain
if (xrc == ReturnCode.XferDone)
{
TWImageInfo imgInfo;
+ TWExtImageInfo extInfo = null;
+ if (SupportedCaps.Contains(CapabilityId.ICapExtImageInfo))
+ {
+ if (DGImage.ExtImageInfo.Get(out extInfo) != ReturnCode.Success)
+ {
+ extInfo = null;
+ }
+ }
if (DGImage.ImageInfo.Get(out imgInfo) != ReturnCode.Success)
{
imgInfo = null;
}
- SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs { FileDataPath = filePath, ImageInfo = imgInfo });
+ SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs
+ {
+ FileDataPath = filePath,
+ ImageInfo = imgInfo,
+ ExImageInfo = extInfo
+ });
+ if (extInfo != null) { extInfo.Dispose(); }
}
else
{
@@ -1000,22 +1029,26 @@ namespace NTwain
if (xrc == ReturnCode.XferDone)
{
TWImageInfo imgInfo;
- //TWExtImageInfo extInfo;
- //if (SupportedCaps.Contains(CapabilityId.ICapExtImageInfo))
- //{
- // if (DGImage.ExtImageInfo.Get(out extInfo) != ReturnCode.Success)
- // {
- // extInfo = null;
- // }
- //}
- if (DGImage.ImageInfo.Get(out imgInfo) == ReturnCode.Success)
+ TWExtImageInfo extInfo = null;
+ if (SupportedCaps.Contains(CapabilityId.ICapExtImageInfo))
{
- SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs { MemData = xferredData.ToArray(), ImageInfo = imgInfo });
+ if (DGImage.ExtImageInfo.Get(out extInfo) != ReturnCode.Success)
+ {
+ extInfo = null;
+ }
}
- else
+ if (DGImage.ImageInfo.Get(out imgInfo) != ReturnCode.Success)
{
- throw new TwainException("Failed to get image info after ImageMemXfer.");
+ imgInfo = null;
}
+
+ SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs
+ {
+ MemData = xferredData.ToArray(),
+ ImageInfo = imgInfo,
+ ExImageInfo = extInfo
+ });
+ if (extInfo != null) { extInfo.Dispose(); }
}
else
{
@@ -1168,11 +1201,25 @@ namespace NTwain
if (File.Exists(finalFile))
{
TWImageInfo imgInfo;
+ TWExtImageInfo extInfo = null;
+ if (SupportedCaps.Contains(CapabilityId.ICapExtImageInfo))
+ {
+ if (DGImage.ExtImageInfo.Get(out extInfo) != ReturnCode.Success)
+ {
+ extInfo = null;
+ }
+ }
if (DGImage.ImageInfo.Get(out imgInfo) != ReturnCode.Success)
{
imgInfo = null;
}
- SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs { FileDataPath = finalFile, ImageInfo = imgInfo });
+ SafeSyncableRaiseOnEvent(OnDataTransferred, DataTransferred, new DataTransferredEventArgs
+ {
+ FileDataPath = finalFile,
+ ImageInfo = imgInfo,
+ ExImageInfo = extInfo
+ });
+ if (extInfo != null) { extInfo.Dispose(); }
}
}
}
diff --git a/NTwain/TwainStateException.cs b/NTwain/TwainStateException.cs
index 5f5b720..6b5b355 100644
--- a/NTwain/TwainStateException.cs
+++ b/NTwain/TwainStateException.cs
@@ -5,118 +5,118 @@ using System.Security.Permissions;
namespace NTwain
{
- ///
- /// Represents an exception from calling a TWAIN triplet operation in the wrong state.
- ///
- [Serializable]
- public class TwainStateException : TwainException
- {
- ///
- /// Initializes a new instance of the class.
- ///
- public TwainStateException() { }
- ///
- /// Initializes a new instance of the class.
- ///
- /// The actual state number.
- /// The minimum state allowed.
- /// The maximum state allowed.
- /// The data group used.
- /// The data argument type used.
- /// The twain message used.
- /// The message.
- public TwainStateException(int currentState, int minStateExpected, int maxStateExpected, DataGroups dataGroup, DataArgumentType argumentType, Message twainMessage, string message)
- : base(message)
- {
- ActualState = currentState;
- MinStateExpected = minStateExpected;
- MaxStateExpected = maxStateExpected;
- DataGroup = dataGroup;
- ArgumentType = argumentType;
- TwainMessage = twainMessage;
- }
+ ///
+ /// Represents an exception from calling a TWAIN triplet operation in the wrong state.
+ ///
+ [Serializable]
+ public class TwainStateException : TwainException
+ {
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ public TwainStateException() { }
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ /// The actual state number.
+ /// The minimum state allowed.
+ /// The maximum state allowed.
+ /// The data group used.
+ /// The data argument type used.
+ /// The twain message used.
+ /// The message.
+ public TwainStateException(int currentState, int minStateExpected, int maxStateExpected, DataGroups dataGroup, DataArgumentType argumentType, Message twainMessage, string message)
+ : base(default(ReturnCode), message)
+ {
+ ActualState = currentState;
+ MinStateExpected = minStateExpected;
+ MaxStateExpected = maxStateExpected;
+ DataGroup = dataGroup;
+ ArgumentType = argumentType;
+ TwainMessage = twainMessage;
+ }
- ///
- /// Initializes a new instance of the class.
- ///
- /// The that holds the serialized object data about the exception being thrown.
- /// The that contains contextual information about the source or destination.
- ///
- /// The parameter is null.
- ///
- ///
- /// The class name is null or is zero (0).
- ///
- protected TwainStateException(SerializationInfo info, StreamingContext context)
- : base(info, context)
- {
- if (info != null)
- {
- MinStateExpected = info.GetInt32("MIN");
- MaxStateExpected = info.GetInt32("MAX");
- ActualState = info.GetInt32("State");
- DataGroup = (DataGroups)info.GetUInt32("DG");
- ArgumentType = (DataArgumentType)info.GetUInt16("DAT");
- TwainMessage = (Message)info.GetUInt16("MSG");
- }
- }
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ /// The that holds the serialized object data about the exception being thrown.
+ /// The that contains contextual information about the source or destination.
+ ///
+ /// The parameter is null.
+ ///
+ ///
+ /// The class name is null or is zero (0).
+ ///
+ protected TwainStateException(SerializationInfo info, StreamingContext context)
+ : base(info, context)
+ {
+ if (info != null)
+ {
+ MinStateExpected = info.GetInt32("MIN");
+ MaxStateExpected = info.GetInt32("MAX");
+ ActualState = info.GetInt32("State");
+ DataGroup = (DataGroups)info.GetUInt32("DG");
+ ArgumentType = (DataArgumentType)info.GetUInt16("DAT");
+ TwainMessage = (Message)info.GetUInt16("MSG");
+ }
+ }
- ///
- /// When overridden in a derived class, sets the with information about the exception.
- ///
- /// The that holds the serialized object data about the exception being thrown.
- /// The that contains contextual information about the source or destination.
- ///
- /// The parameter is a null reference (Nothing in Visual Basic).
- ///
- ///
- ///
- ///
- ///
- [SecurityPermissionAttribute(SecurityAction.Demand, SerializationFormatter = true)]
- public override void GetObjectData(SerializationInfo info, StreamingContext context)
- {
- if (info != null)
- {
- info.AddValue("MIN", MinStateExpected);
- info.AddValue("MAX", MaxStateExpected);
- info.AddValue("State", ActualState);
- info.AddValue("DG", DataGroup);
- info.AddValue("DAT", ArgumentType);
- info.AddValue("MSG", TwainMessage);
- }
- base.GetObjectData(info, context);
- }
+ ///
+ /// When overridden in a derived class, sets the with information about the exception.
+ ///
+ /// The that holds the serialized object data about the exception being thrown.
+ /// The that contains contextual information about the source or destination.
+ ///
+ /// The parameter is a null reference (Nothing in Visual Basic).
+ ///
+ ///
+ ///
+ ///
+ ///
+ [SecurityPermissionAttribute(SecurityAction.Demand, SerializationFormatter = true)]
+ public override void GetObjectData(SerializationInfo info, StreamingContext context)
+ {
+ if (info != null)
+ {
+ info.AddValue("MIN", MinStateExpected);
+ info.AddValue("MAX", MaxStateExpected);
+ info.AddValue("State", ActualState);
+ info.AddValue("DG", DataGroup);
+ info.AddValue("DAT", ArgumentType);
+ info.AddValue("MSG", TwainMessage);
+ }
+ base.GetObjectData(info, context);
+ }
- ///
- /// Gets the allowed minimum state.
- ///
- /// The minimum.
- public int MinStateExpected { get; private set; }
- ///
- /// Gets the allowed maximum state.
- ///
- /// The maximum.
- public int MaxStateExpected { get; private set; }
- ///
- /// Gets the actual state number.
- ///
- /// The state.
- public int ActualState { get; private set; }
- ///
- /// Gets the triplet data group.
- ///
- /// The data group.
- public DataGroups DataGroup { get; private set; }
- ///
- /// Gets the triplet data argument type.
- ///
- /// The type of the argument.
- public DataArgumentType ArgumentType { get; private set; }
- ///
- /// Gets the triplet message.
- ///
- /// The twain message.
- public Message TwainMessage { get; private set; }
- }
+ ///
+ /// Gets the allowed minimum state.
+ ///
+ /// The minimum.
+ public int MinStateExpected { get; private set; }
+ ///
+ /// Gets the allowed maximum state.
+ ///
+ /// The maximum.
+ public int MaxStateExpected { get; private set; }
+ ///
+ /// Gets the actual state number.
+ ///
+ /// The state.
+ public int ActualState { get; private set; }
+ ///
+ /// Gets the triplet data group.
+ ///
+ /// The data group.
+ public DataGroups DataGroup { get; private set; }
+ ///
+ /// Gets the triplet data argument type.
+ ///
+ /// The type of the argument.
+ public DataArgumentType ArgumentType { get; private set; }
+ ///
+ /// Gets the triplet message.
+ ///
+ /// The twain message.
+ public Message TwainMessage { get; private set; }
+ }
}
diff --git a/NTwain/TwainException.cs b/NTwain/TwainException.cs
index 0a72ba0..2b926ee 100644
--- a/NTwain/TwainException.cs
+++ b/NTwain/TwainException.cs
@@ -1,46 +1,89 @@
-using System;
+using NTwain.Values;
+using System;
using System.Runtime.Serialization;
+using System.Security.Permissions;
namespace NTwain
{
- ///
- /// Represents a general exception with TWAIN.
- ///
- [Serializable]
- public class TwainException : Exception
- {
- ///
- /// Initializes a new instance of the class.
- ///
- public TwainException() { }
+ ///
+ /// Represents a general exception with TWAIN.
+ ///
+ [Serializable]
+ public class TwainException : Exception
+ {
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ public TwainException() { }
- ///
- /// Initializes a new instance of the class.
- ///
- /// The message.
- public TwainException(string message)
- : base(message) { }
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ /// The return code.
+ /// The message.
+ public TwainException(ReturnCode returnCode, string message)
+ : this(returnCode, message, null) { }
- ///
- /// Initializes a new instance of the class.
- ///
- /// The message.
- /// The inner exception.
- public TwainException(string message, Exception innerException)
- : base(message, innerException) { }
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ /// The return code.
+ /// The message.
+ /// The inner exception.
+ public TwainException(ReturnCode returnCode, string message, Exception innerException)
+ : base(message, innerException)
+ {
+ ReturnCode = returnCode;
+ }
- ///
- /// Initializes a new instance of the class.
- ///
- /// The that holds the serialized object data about the exception being thrown.
- /// The that contains contextual information about the source or destination.
- ///
- /// The parameter is null.
- ///
- ///
- /// The class name is null or is zero (0).
- ///
- protected TwainException(SerializationInfo info, StreamingContext context)
- : base(info, context) { }
- }
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ /// The that holds the serialized object data about the exception being thrown.
+ /// The that contains contextual information about the source or destination.
+ ///
+ /// The parameter is null.
+ ///
+ ///
+ /// The class name is null or is zero (0).
+ ///
+ protected TwainException(SerializationInfo info, StreamingContext context)
+ : base(info, context)
+ {
+ if (info != null)
+ {
+ ReturnCode = (ReturnCode)info.GetUInt16("RC");
+ }
+ }
+
+ ///
+ /// When overridden in a derived class, sets the with information about the exception.
+ ///
+ /// The that holds the serialized object data about the exception being thrown.
+ /// The that contains contextual information about the source or destination.
+ ///
+ /// The parameter is a null reference (Nothing in Visual Basic).
+ ///
+ ///
+ ///
+ ///
+ ///
+ [SecurityPermissionAttribute(SecurityAction.Demand, SerializationFormatter = true)]
+ public override void GetObjectData(SerializationInfo info, StreamingContext context)
+ {
+ if (info != null)
+ {
+ info.AddValue("RC", ReturnCode);
+ }
+ base.GetObjectData(info, context);
+ }
+
+ ///
+ /// Gets the return code from the TWAIN operation if applicable.
+ ///
+ ///
+ /// The return code.
+ ///
+ public ReturnCode ReturnCode { get; private set; }
+ }
}